<?php
// Ensure user is authenticated
if (!isset($_SESSION['COMPANY_USERID'])) {
    redirect(web_root . "admin/index.php");
}

// Define the formatLevel function
function formatLevel($averageLevel) {
    $level = round($averageLevel);
    $map = [1 => 'I', 2 => 'II', 3 => 'III', 4 => 'IV', 5 => 'V', 6 => 'VI', 7 => 'VII', 8 => 'VIII', 9 => 'IX', 10 => 'X'];
    return $map[$level] ?? 'N/A';
}

// Fetch all schools and their corresponding average levels
$sql = "
    SELECT s.SCHOOLNAME, AVG(sur.SurveyAverage) AS AverageLevel
    FROM tblschools s
    LEFT JOIN tblsurvey sur ON s.SCHOOLNAME = sur.SchoolName
    GROUP BY s.SCHOOLNAME
    ORDER BY s.SCHOOLNAME
"; 
$mydb->setQuery($sql);
$schools = $mydb->loadResultList();
?>

<div class="card">
    <div class="card-header">
        <h3 class="card-title">Departments / Schools</h3>
        <div class="card-tools">
            <button type="button" class="btn btn-tool" data-card-widget="collapse"><i class="fas fa-minus"></i></button>
            <button type="button" class="btn btn-tool" data-card-widget="remove"><i class="fas fa-times"></i></button>
        </div>
    </div>
    <div class="card-body">
       <div class="row">
    <?php foreach ($schools as $school): ?>
        <div class="col-lg-4 col-md-6 col-sm-12 mb-3">
        <a href="details.php?school=<?php echo urlencode($school->SCHOOLNAME); ?>" class="text-decoration-none">
        <div class="card text-center shadow-sm">
                    <div class="card-body">
                        <h5 class="card-title"><?php echo htmlspecialchars($school->SCHOOLNAME); ?></h5>
                        <p class="card-text">Average Level: <strong><?php echo formatLevel($school->AverageLevel); ?></strong></p>
                    </div>
                    <div class="card-footer bg-light">
                        <small class="text-muted">Click for details</small>
                    </div>
                </div>
            </a>
        </div>
    <?php endforeach; ?>
</div>

    </div>
    <div class="card-footer text-center">Updated dynamically</div>
</div>

<style>

    body {
       font-family: Arial, sans-serif;
       background-color: #f8f9fa;
       margin: 0;
       padding: 20px;
    }
    .container {
        width: 90%;
        margin: auto;
    }
    .dashboard-header {
         font-size: 24px;
         margin-bottom: 10px;
    }
    .dashboard-box {
         background: white;
         padding: 15px;
         border-radius: 8px;
         box-shadow: 0 2px 5px rgba(0,0,0,0.1);
     }
     .dashboard-title {
         font-weight: bold;
         margin: 0;
    }
    .cards-container {
         display: flex;
         flex-wrap: wrap;
         gap: 15px;
         margin-top: 15px;
    }
    .card {
         flex: 1;
         min-width: 250px;
         background: white;
         padding: 20px;
         border-radius: 8px;
         box-shadow: 0 2px 4px rgba(0,0,0,0.1);
         text-align: center;

    }
    .card:hover {
        transform: translateY(-5px);
        box-shadow: 0px 10px 15px rgba(0, 0, 0, 0.1);
    }
    .card-title {
        font-size: 1.2rem;
        font-weight: bold;
        color: #333;
        margin: 0 ;
    }
    .card-text {
        font-size: 1rem;
        color: #555;
        margin: 5px 0;
    }
    .card-text strong {
        font-weight: bold;
   }
        .card-footer {
            color: gray;
            font-size: 14px
   }
   .updated-text {
            text-align: center;
            margin-top: 20px;
            color: gray;
            font-weight: bold;
   }
</style>
